
ALTER TABLE rv_affiliates
  ADD COLUMN is_mediation INTEGER NOT NULL;

-- Add the 'affiliate_type' column
ALTER TABLE rv_affiliates
  ADD COLUMN affiliate_type INTEGER NOT NULL;
  COMMENT ON COLUMN rv_affiliates.affiliate_type IS '1-Android, 2-Website, 3-IOS';




-- 1. Create the table with BIGSERIAL for auto-incrementing network_id
CREATE TABLE mediation_networks (
  network_id BIGSERIAL PRIMARY KEY,
  account_id BIGINT NOT NULL,
  network_name VARCHAR(100) NOT NULL,
  status SMALLINT NOT NULL CHECK (status IN (0, 1)), -- 1-active, 0-paused
  tot_no_param INTEGER NOT NULL,
  is_custom SMALLINT NOT NULL DEFAULT 0 CHECK (is_custom IN (0, 1)), -- 0-no, 1-yes
  is_default_net SMALLINT NOT NULL DEFAULT 0 CHECK (is_default_net IN (0, 1)) -- 0-network, 1-marketplace
);

-- 2. Add comments on the appropriate columns
COMMENT ON COLUMN mediation_networks.status IS '1-active, 0-paused';
COMMENT ON COLUMN mediation_networks.is_custom IS '0-no, 1-yes';
COMMENT ON COLUMN mediation_networks.is_default_net IS '0-network, 1-marketplace';



CREATE TABLE mediation_site_categories (
  category_id INTEGER NOT NULL, 
  category_name VARCHAR(50) NOT NULL, 
  value VARCHAR(10) NOT NULL, 
  description TEXT NOT NULL, 
  parent_category_id VARCHAR(10) NOT NULL DEFAULT '0', 
  is_deleted SMALLINT NOT NULL DEFAULT 0, 
  is_blocked INTEGER NOT NULL DEFAULT 0
);



INSERT INTO mediation_site_categories (category_id, category_name, value, description, parent_category_id, is_deleted, is_blocked) VALUES
(1, 'Arts & Entertainment', 'IAB1', '', '0', 0, 0),
(2, 'Books & Literature', 'IAB1-1', '', 'IAB1', 0, 0),
(4, 'Celebrity Fan/Gossip', 'IAB1-2', '', 'IAB1', 0, 0),
(5, 'Fine Art', 'IAB1-3', '', 'IAB1', 0, 0),
(6, 'Humor', 'IAB1-4', '', 'IAB1', 0, 0),
(7, 'Movies', 'IAB1-5', '', 'IAB1', 0, 0),
(8, 'Music', 'IAB1-6', '', 'IAB1', 0, 0),
(9, 'Television', 'IAB1-7', '', 'IAB1', 0, 0),
(10, 'Automotive', 'IAB2', '', '0', 0, 0),
(11, 'Auto Parts', 'IAB2-1', '', 'IAB2', 0, 0),
(12, 'Auto Repair', 'IAB2-2', '', 'IAB2', 0, 0),
(13, 'Buying/Selling Cars', 'IAB2-3', '', 'IAB2', 0, 0),
(14, 'Car Culture', 'IAB2-4', '', 'IAB2', 0, 0),
(15, 'Certified Pre-Owned', 'IAB2-5', '', 'IAB2', 0, 0),
(16, 'Convertible', 'IAB2-6', '', 'IAB2', 0, 0),
(17, 'Coupe', 'IAB2-7', '', 'IAB2', 0, 0),
(18, 'Crossover', 'IAB2-8', '', 'IAB2', 0, 0),
(19, 'Diesel', 'IAB2-9', '', 'IAB2', 0, 0),
(20, 'Electric Vehicle', 'IAB2-10', '', 'IAB2', 0, 0),
(21, 'Hatchback', 'IAB2-11', '', 'IAB2', 0, 0),
(22, 'Hybrid', 'IAB2-12', '', 'IAB2', 0, 0),
(23, 'Luxury', 'IAB2-13', '', 'IAB2', 0, 0),
(24, 'MiniVan', 'IAB2-14', '', 'IAB2', 0, 0),
(25, 'Motorcycles', 'IAB2-15', '', 'IAB2', 0, 0),
(26, 'Off-Road Vehicles', 'IAB2-16', '', 'IAB2', 0, 0),
(27, 'Performance Vehicles', 'IAB2-17', '', 'IAB2', 0, 0),
(28, 'Pickup', 'IAB2-18', '', 'IAB2', 0, 0),
(29, 'Road-Side Assistance', 'IAB2-19', '', 'IAB2', 0, 0),
(30, 'Sedan', 'IAB2-20', '', 'IAB2', 0, 0),
(31, 'Trucks & Accessories', 'IAB2-21', '', 'IAB2', 0, 0),
(32, 'Vintage Cars', 'IAB2-22', '', 'IAB2', 0, 0),
(33, 'Wagon', 'IAB2-23', '', 'IAB2', 0, 0),
(34, 'Business', 'IAB3', '', '0', 0, 0),
(35, 'Advertising', 'IAB3-1', '', 'IAB3', 0, 0),
(36, 'Agriculture', 'IAB3-2', '', 'IAB3', 0, 0),
(37, 'Biotech/Biomedical', 'IAB3-3', '', 'IAB3', 0, 0),
(38, 'Business Software', 'IAB3-4', '', 'IAB3', 0, 0),
(39, 'Construction', 'IAB3-5', '', 'IAB3', 0, 0),
(40, 'Forestry', 'IAB3-6', '', 'IAB3', 0, 0),
(41, 'Government', 'IAB3-7', '', 'IAB3', 0, 0),
(42, 'Green Solutions', 'IAB3-8', '', 'IAB3', 0, 0),
(43, 'Human Resources', 'IAB3-9', '', 'IAB3', 0, 0),
(44, 'Logistics', 'IAB3-10', '', 'IAB3', 0, 0),
(45, 'Marketing', 'IAB3-11', '', 'IAB3', 0, 0),
(46, 'Metals', 'IAB3-12', '', 'IAB3', 0, 0),
(47, 'Careers', 'IAB4', '', '0', 0, 0),
(48, 'Career Planning', 'IAB4-1', '', 'IAB4', 0, 0),
(49, 'College', 'IAB4-2', '', 'IAB4', 0, 0),
(50, 'Financial Aid', 'IAB4-3', '', 'IAB4', 0, 0),
(51, 'Job Fairs', 'IAB4-4', '', 'IAB4', 0, 0),
(52, 'Job Search', 'IAB4-5', '', 'IAB4', 0, 0),
(53, 'Resume Writing/Advice', 'IAB4-6', '', 'IAB4', 0, 0),
(54, 'Nursing', 'IAB4-7', '', 'IAB4', 0, 0),
(55, 'Scholarships', 'IAB4-8', '', 'IAB4', 0, 0),
(56, 'Telecommuting', 'IAB4-9', '', 'IAB4', 0, 0),
(57, 'U.S. Military', 'IAB4-10', '', 'IAB4', 0, 0),
(58, 'Career Advice', 'IAB4-11', '', 'IAB4', 0, 0),
(59, 'Education', 'IAB5', '', '0', 0, 0),
(60, '7-12 Education', 'IAB5-1', '', 'IAB5', 0, 0),
(61, 'Adult Education', 'IAB5-2', '', 'IAB5', 0, 0),
(62, 'Art History', 'IAB5-3', '', 'IAB5', 0, 0),
(63, 'Colledge Administration', 'IAB5-4', '', 'IAB5', 0, 0),
(64, 'College Life', 'IAB5-5', '', 'IAB5', 0, 0),
(65, 'Distance Learning', 'IAB5-6', '', 'IAB5', 0, 0),
(66, 'English as a 2nd Language', 'IAB5-7', '', 'IAB5', 0, 0),
(67, 'Language Learning', 'IAB5-8', '', 'IAB5', 0, 0),
(68, 'Graduate School', 'IAB5-9', '', 'IAB5', 0, 0),
(69, 'Homeschooling', 'IAB5-10', '', 'IAB5', 0, 0),
(70, 'Homework/Study Tips', 'IAB5-11', '', 'IAB5', 0, 0),
(71, 'K-6 Educators', 'IAB5-12', '', 'IAB5', 0, 0),
(72, 'Private School', 'IAB5-13', '', 'IAB5', 0, 0),
(73, 'Special Education', 'IAB5-14', '', 'IAB5', 0, 0),
(74, 'Studying Business', 'IAB5-15', '', 'IAB5', 0, 0),
(75, 'Family & Parenting', 'IAB6', '', '0', 0, 0),
(76, 'Adoption', 'IAB6-1', '', 'IAB6', 0, 0),
(77, 'Babies & Toddlers', 'IAB6-2', '', 'IAB6', 0, 0),
(78, 'Daycare/Pre School', 'IAB6-3', '', 'IAB6', 0, 0),
(79, 'Family Internet', 'IAB6-4', '', 'IAB6', 0, 0),
(80, 'Parenting - K-6 Kids', 'IAB6-5', '', 'IAB6', 0, 0),
(81, 'Parenting teens', 'IAB6-6', '', 'IAB6', 0, 0),
(82, 'Pregnancy', 'IAB6-7', '', 'IAB6', 0, 0),
(83, 'Special Needs Kids', 'IAB6-8', '', 'IAB6', 0, 0),
(84, 'Eldercare', 'IAB6-9', '', 'IAB6', 0, 0),
(85, 'Health & Fitness', 'IAB7', '', '0', 0, 0),
(86, 'Exercise', 'IAB7-1', '', 'IAB7', 0, 0),
(87, 'A.D.D.', 'IAB7-2', '', 'IAB7', 0, 0),
(88, 'AIDS/HIV', 'IAB7-3', '', 'IAB7', 0, 0),
(89, 'Allergies', 'IAB7-4', '', 'IAB7', 0, 0),
(90, 'Alternative Medicine', 'IAB7-5', '', 'IAB7', 0, 0),
(91, 'Arthritis', 'IAB7-6', '', 'IAB7', 0, 0),
(92, 'Asthma', 'IAB7-7', '', 'IAB7', 0, 0),
(93, 'Autism/PDD', 'IAB7-8', '', 'IAB7', 0, 0),
(94, 'Bipolar Disorder', 'IAB7-9', '', 'IAB7', 0, 0),
(95, 'Brain Tumor', 'IAB7-10', '', 'IAB7', 0, 0),
(96, 'Cancer', 'IAB7-11', '', 'IAB7', 0, 0),
(97, 'Cholesterol', 'IAB7-12', '', 'IAB7', 0, 0),
(98, 'Chronic Fatigue Syndrome', 'IAB7-13', '', 'IAB7', 0, 0),
(99, 'Chronic Pain', 'IAB7-14', '', 'IAB7', 0, 0),
(100, 'Cold & Flu', 'IAB7-15', '', 'IAB7', 0, 0),
(101, 'Deafness', 'IAB7-16', '', 'IAB7', 0, 0),
(102, 'Dental Care', 'IAB7-17', '', 'IAB7', 0, 0),
(103, 'Depression', 'IAB7-18', '', 'IAB7', 0, 0),
(104, 'Dermatology', 'IAB7-19', '', 'IAB7', 0, 0),
(105, 'Diabetes', 'IAB7-20', '', 'IAB7', 0, 0),
(106, 'Epilepsy', 'IAB7-21', '', 'IAB7', 0, 0),
(107, 'GERD/Acid Reflux', 'IAB7-22', '', 'IAB7', 0, 0),
(108, 'Headaches/Migraines', 'IAB7-23', '', 'IAB7', 0, 0),
(109, 'Heart Disease', 'IAB7-24', '', 'IAB7', 0, 0),
(110, 'Herbs for Health', 'IAB7-25', '', 'IAB7', 0, 0),
(111, 'Holistic Healing', 'IAB7-26', '', 'IAB7', 0, 0),
(112, 'IBS/Crohn\s Disease', 'IAB7-27', '', 'IAB7', 0, 0),
(113, 'Incest/Abuse Support', 'IAB7-28', '', 'IAB7', 0, 0),
(114, 'Incontinence', 'IAB7-29', '', 'IAB7', 0, 0),
(115, 'Infertility', 'IAB7-30', '', 'IAB7', 0, 0),
(116, 'Men\s Health', 'IAB7-31', '', 'IAB7', 0, 0),
(117, 'Nutrition', 'IAB7-32', '', 'IAB7', 0, 0),
(118, 'Orthopedics', 'IAB7-33', '', 'IAB7', 0, 0),
(119, 'Panic/Anxiety Disorders', 'IAB7-34', '', 'IAB7', 0, 0),
(120, 'Pediatrics', 'IAB7-35', '', 'IAB7', 0, 0),
(121, 'Physical Therapy', 'IAB7-36', '', 'IAB7', 0, 0),
(122, 'Psychology/Psychiatry', 'IAB7-37', '', 'IAB7', 0, 0),
(123, 'Senor Health', 'IAB7-38', '', 'IAB7', 0, 0),
(124, 'Sexuality', 'IAB7-39', '', 'IAB7', 0, 0),
(125, 'Sleep Disorders', 'IAB7-40', '', 'IAB7', 0, 0),
(126, 'Smoking Cessation', 'IAB7-41', '', 'IAB7', 0, 0),
(127, 'Substance Abuse', 'IAB7-42', '', 'IAB7', 0, 0),
(128, 'Thyroid Disease', 'IAB7-43', '', 'IAB7', 0, 0),
(129, 'Weight Loss', 'IAB7-44', '', 'IAB7', 0, 0),
(130, 'Women\s Health', 'IAB7-45', '', 'IAB7', 0, 0),
(131, 'Food & Drink', 'IAB8', '', '0', 0, 0),
(132, 'American Cuisine', 'IAB8-1', '', 'IAB8', 0, 0),
(133, 'Barbecues & Grilling', 'IAB8-2', '', 'IAB8', 0, 0),
(134, 'Cajun/Creole', 'IAB8-3', '', 'IAB8', 0, 0),
(135, 'Chinese Cuisine', 'IAB8-4', '', 'IAB8', 0, 0),
(136, 'Cocktails/Beer', 'IAB8-5', '', 'IAB8', 0, 0),
(137, 'Coffee/Tea', 'IAB8-6', '', 'IAB8', 0, 0),
(138, 'Cuisine-Specific', 'IAB8-7', '', 'IAB8', 0, 0),
(139, 'Desserts & Baking', 'IAB8-8', '', 'IAB8', 0, 0),
(140, 'Dining Out', 'IAB8-9', '', 'IAB8', 0, 0),
(141, 'Food Allergies', 'IAB8-10', '', 'IAB8', 0, 0),
(142, 'French Cuisine', 'IAB8-11', '', 'IAB8', 0, 0),
(143, 'Health/Lowfat Cooking', 'IAB8-12', '', 'IAB8', 0, 0),
(144, 'Italian Cuisine', 'IAB8-13', '', 'IAB8', 0, 0),
(145, 'Japanese Cuisine', 'IAB8-14', '', 'IAB8', 0, 0),
(146, 'Mexican Cuisine', 'IAB8-15', '', 'IAB8', 0, 0),
(147, 'Vegan', 'IAB8-16', '', 'IAB8', 0, 0),
(148, 'Vegetarian', 'IAB8-17', '', 'IAB8', 0, 0),
(149, 'Wine', 'IAB8-18', '', 'IAB8', 0, 0),
(151, 'Hobbies & Interests', 'IAB9', '', '0', 0, 0),
(152, 'Art/Technology', 'IAB9-1', '', 'IAB9', 0, 0),
(153, 'Arts & Crafts', 'IAB9-2', '', 'IAB9', 0, 0),
(154, 'Beadwork', 'IAB9-3', '', 'IAB9', 0, 0),
(155, 'Birdwatching', 'IAB9-4', '', 'IAB9', 0, 0),
(156, 'Board Games/Puzzles', 'IAB9-5', '', 'IAB9', 0, 0),
(157, 'Candle & Soap Making', 'IAB9-6', '', 'IAB9', 0, 0),
(158, 'Card Games', 'IAB9-7', '', 'IAB9', 0, 0),
(159, 'Chess', 'IAB9-8', '', 'IAB9', 0, 0),
(160, 'Cigars', 'IAB9-9', '', 'IAB9', 0, 0),
(161, 'Collecting', 'IAB9-10', '', 'IAB9', 0, 0),
(162, 'Comic Books', 'IAB9-11', '', 'IAB9', 0, 0),
(163, 'Drawing/Sketching', 'IAB9-12', '', 'IAB9', 0, 0),
(164, 'Freelance Writing', 'IAB9-13', '', 'IAB9', 0, 0),
(165, 'Genealogy', 'IAB9-14', '', 'IAB9', 0, 0),
(166, 'Getting Published', 'IAB9-15', '', 'IAB9', 0, 0),
(167, 'Guitar', 'IAB9-16', '', 'IAB9', 0, 0),
(168, 'Home Recording', 'IAB9-17', '', 'IAB9', 0, 0),
(169, 'Investors & Patents', 'IAB9-18', '', 'IAB9', 0, 0),
(170, 'Jewelry Making', 'IAB9-19', '', 'IAB9', 0, 0),
(171, 'Magic & Illusion', 'IAB9-20', '', 'IAB9', 0, 0),
(172, 'Needlework', 'IAB9-21', '', 'IAB9', 0, 0),
(173, 'Painting', 'IAB9-22', '', 'IAB9', 0, 0),
(174, 'Photography', 'IAB9-23', '', 'IAB9', 0, 0),
(175, 'Radio', 'IAB9-24', '', 'IAB9', 0, 0),
(176, 'Roleplaying Games', 'IAB9-25', '', 'IAB9', 0, 0),
(177, 'Sci-Fi & Fantasy', 'IAB9-26', '', 'IAB9', 0, 0),
(178, 'Scrapbooking', 'IAB9-27', '', 'IAB9', 0, 0),
(179, 'Screenwriting', 'IAB9-28', '', 'IAB9', 0, 0),
(180, 'Stamps & Coins', 'IAB9-29', '', 'IAB9', 0, 0),
(181, 'Video & Computer Games', 'IAB9-30', '', 'IAB9', 0, 0),
(182, 'Woodworking', 'IAB9-31', '', 'IAB9', 0, 0),
(184, 'Home & Garden', 'IAB10', '', '0', 0, 0),
(185, 'Appliances', 'IAB10-1', '', 'IAB10', 0, 0),
(186, 'Entertaining', 'IAB10-2', '', 'IAB10', 0, 0),
(187, 'Environmental Safety', 'IAB10-3', '', 'IAB10', 0, 0),
(188, 'Gardening', 'IAB10-4', '', 'IAB10', 0, 0),
(189, 'Home Repair', 'IAB10-5', '', 'IAB10', 0, 0),
(190, 'Home Theater', 'IAB10-6', '', 'IAB10', 0, 0),
(191, 'Interior Decorating', 'IAB10-7', '', 'IAB10', 0, 0),
(192, 'Landscaping', 'IAB10-8', '', 'IAB10', 0, 0),
(193, 'Remodeling & Construction', 'IAB10-9', '', 'IAB10', 0, 0),
(194, 'Law, Gov\t & Politics', 'IAB11', '', '0', 0, 0),
(195, 'Immigration', 'IAB11-1', '', 'IAB11', 0, 0),
(196, 'Legal Issues', 'IAB11-2', '', 'IAB11', 0, 0),
(197, 'U.S. Government Resources', 'IAB11-3', '', 'IAB11', 0, 0),
(198, 'Politics', 'IAB11-4', '', 'IAB11', 0, 0),
(199, 'Commentary', 'IAB11-5', '', 'IAB11', 0, 0),
(200, 'News', 'IAB12', '', '0', 0, 0),
(201, 'International News', 'IAB12-1', '', 'IAB12', 0, 0),
(202, 'National News', 'IAB12-2', '', 'IAB12', 0, 0),
(203, 'Local News', 'IAB12-3', '', 'IAB12', 0, 0),
(204, 'Personal Finance', 'IAB13', '', '0', 0, 0),
(205, 'Beginning Investing', 'IAB13-1', '', 'IAB13', 0, 0),
(206, 'Credit/Debt & Loans', 'IAB13-2', '', 'IAB13', 0, 0),
(207, 'Financial News', 'IAB13-3', '', 'IAB13', 0, 0),
(208, 'Financial Planning', 'IAB13-4', '', 'IAB13', 0, 0),
(209, 'Hedge Fund', 'IAB13-5', '', 'IAB13', 0, 0),
(210, 'Insurance', 'IAB13-6', '', 'IAB13', 0, 0),
(211, 'Investing', 'IAB13-7', '', 'IAB13', 0, 0),
(212, 'Mutual Funds', 'IAB13-8', '', 'IAB13', 0, 0),
(213, 'Options', 'IAB13-9', '', 'IAB13', 0, 0),
(214, 'Retirement Planning', 'IAB13-10', '', 'IAB13', 0, 0),
(215, 'Stocks', 'IAB13-11', '', 'IAB13', 0, 0),
(216, 'Tax Planning', 'IAB13-12', '', 'IAB13', 0, 0),
(217, 'Society', 'IAB14', '', '0', 0, 0),
(218, 'Dating', 'IAB14-1', '', 'IAB14', 0, 0),
(219, 'Divorce Support', 'IAB14-2', '', 'IAB14', 0, 0),
(220, 'Gay Life', 'IAB14-3', '', 'IAB14', 0, 0),
(221, 'Marriage', 'IAB14-4', '', 'IAB14', 0, 0),
(222, 'Senior Living', 'IAB14-5', '', 'IAB14', 0, 0),
(223, 'Teens', 'IAB14-6', '', 'IAB14', 0, 0),
(224, 'Weddings', 'IAB14-7', '', 'IAB14', 0, 0),
(225, 'Ethnic Specific', 'IAB14-8', '', 'IAB14', 0, 0),
(226, 'Science', 'IAB15', '', '0', 0, 0),
(227, 'Astrology', 'IAB15-1', '', 'IAB15', 0, 0),
(228, 'Biology', 'IAB15-2', '', 'IAB15', 0, 0),
(229, 'Chemistry', 'IAB15-3', '', 'IAB15', 0, 0),
(230, 'Geology', 'IAB15-4', '', 'IAB15', 0, 0),
(231, 'Paranormal Phenomena', 'IAB15-5', '', 'IAB15', 0, 0),
(232, 'Physics', 'IAB15-6', '', 'IAB15', 0, 0),
(233, 'Space/Astronomy', 'IAB15-7', '', 'IAB15', 0, 0),
(234, 'Geography', 'IAB15-8', '', 'IAB15', 0, 0),
(235, 'Botany', 'IAB15-9', '', 'IAB15', 0, 0),
(236, 'Weather', 'IAB15-10', '', 'IAB15', 0, 0),
(237, 'Pets', 'IAB16', '', '0', 0, 0),
(238, 'Aquariums', 'IAB16-1', '', 'IAB16', 0, 0),
(239, 'Birds', 'IAB16-2', '', 'IAB16', 0, 0),
(240, 'Cats', 'IAB16-3', '', 'IAB16', 0, 0),
(241, 'Dogs', 'IAB16-4', '', 'IAB16', 0, 0),
(242, 'Large Animals', 'IAB16-5', '', 'IAB16', 0, 0),
(243, 'Reptiles', 'IAB16-6', '', 'IAB16', 0, 0),
(244, 'Veterinary Medicine', 'IAB16-7', '', 'IAB16', 0, 0),
(245, 'Sports', 'IAB17', '', '0', 0, 0),
(246, 'Auto Racing', 'IAB17-1', '', 'IAB17', 0, 0),
(247, 'Baseball', 'IAB17-2', '', 'IAB17', 0, 0),
(248, 'Bicycling', 'IAB17-3', '', 'IAB17', 0, 0),
(249, 'Bodybuilding', 'IAB17-4', '', 'IAB17', 0, 0),
(250, 'Boxing', 'IAB17-5', '', 'IAB17', 0, 0),
(251, 'Canoeing/Kayaking', 'IAB17-6', '', 'IAB17', 0, 0),
(252, 'Cheerleading', 'IAB17-7', '', 'IAB17', 0, 0),
(253, 'Climbing', 'IAB17-8', '', 'IAB17', 0, 0),
(254, 'Cricket', 'IAB17-9', '', 'IAB17', 0, 0),
(255, 'Figure Skating', 'IAB17-10', '', 'IAB17', 0, 0),
(256, 'Fly Fishing', 'IAB17-11', '', 'IAB17', 0, 0),
(257, 'Football', 'IAB17-12', '', 'IAB17', 0, 0),
(258, 'Freshwater Fishing', 'IAB17-13', '', 'IAB17', 0, 0),
(259, 'Game & Fish', 'IAB17-14', '', 'IAB17', 0, 0),
(260, 'Golf', 'IAB17-15', '', 'IAB17', 0, 0),
(261, 'Horse Racing', 'IAB17-16', '', 'IAB17', 0, 0),
(262, 'Horses', 'IAB17-17', '', 'IAB17', 0, 0),
(263, 'Hunting/Shooting', 'IAB17-18', '', 'IAB17', 0, 0),
(264, 'Inline Skating', 'IAB17-19', '', 'IAB17', 0, 0),
(265, 'Martial Arts', 'IAB17-20', '', 'IAB17', 0, 0),
(266, 'Mountain Biking', 'IAB17-21', '', 'IAB17', 0, 0),
(267, 'NASCAR Racing', 'IAB17-22', '', 'IAB17', 0, 0),
(268, 'Olympics', 'IAB17-23', '', 'IAB17', 0, 0),
(269, 'Paintball', 'IAB17-24', '', 'IAB17', 0, 0),
(270, 'Power & Motorcycles', 'IAB17-25', '', 'IAB17', 0, 0),
(271, 'Pro Basketball', 'IAB17-26', '', 'IAB17', 0, 0),
(272, 'Pro Ice Hockey', 'IAB17-27', '', 'IAB17', 0, 0),
(273, 'Rodeo', 'IAB17-28', '', 'IAB17', 0, 0),
(274, 'Rugby', 'IAB17-29', '', 'IAB17', 0, 0),
(275, 'Running/Jogging', 'IAB17-30', '', 'IAB17', 0, 0),
(276, 'Sailing', 'IAB17-31', '', 'IAB17', 0, 0),
(277, 'Saltwater Fishing', 'IAB17-32', '', 'IAB17', 0, 0),
(278, 'Scuba Diving', 'IAB17-33', '', 'IAB17', 0, 0),
(279, 'Skateboarding', 'IAB17-34', '', 'IAB17', 0, 0),
(280, 'Skiing', 'IAB17-35', '', 'IAB17', 0, 0),
(281, 'Snowboarding', 'IAB17-36', '', 'IAB17', 0, 0),
(282, 'Surfing/Bodyboarding', 'IAB17-37', '', 'IAB17', 0, 0),
(283, 'Swimming', 'IAB17-38', '', 'IAB17', 0, 0),
(284, 'Table Tennis/Ping-Pong', 'IAB17-39', '', 'IAB17', 0, 0),
(285, 'Tennis', 'IAB17-40', '', 'IAB17', 0, 0),
(286, 'Volleyball', 'IAB17-41', '', 'IAB17', 0, 0),
(287, 'Walking', 'IAB17-42', '', 'IAB17', 0, 0),
(288, 'Waterski/Wakeboard', 'IAB17-43', '', 'IAB17', 0, 0),
(289, 'World Soccer', 'IAB17-44', '', 'IAB17', 0, 0),
(290, 'Style & Fashion', 'IAB18', '', '0', 0, 0),
(291, 'Beauty', 'IAB18-1', '', 'IAB18', 0, 0),
(292, 'Body Art', 'IAB18-2', '', 'IAB18', 0, 0),
(293, 'Fashion', 'IAB18-3', '', 'IAB18', 0, 0),
(294, 'Jewelry', 'IAB18-4', '', 'IAB18', 0, 0),
(295, 'Clothing', 'IAB18-5', '', 'IAB18', 0, 0),
(296, 'Accessories', 'IAB18-6', '', 'IAB18', 0, 0),
(297, 'Technology & Computing', 'IAB19', '', '0', 0, 0),
(298, '3-D Graphics', 'IAB19-1', '', 'IAB19', 0, 0),
(299, 'Animation', 'IAB19-2', '', 'IAB19', 0, 0),
(300, 'Antivirus Software', 'IAB19-3', '', 'IAB19', 0, 0),
(301, 'C/C++', 'IAB19-4', '', 'IAB19', 0, 0),
(302, 'Cameras & Camcorders', 'IAB19-5', '', 'IAB19', 0, 0),
(303, 'Cell Phones', 'IAB19-6', '', 'IAB19', 0, 0),
(304, 'Computer Certification', 'IAB19-7', '', 'IAB19', 0, 0),
(305, 'Computer Networking', 'IAB19-8', '', 'IAB19', 0, 0),
(306, 'Computer Peripherals', 'IAB19-9', '', 'IAB19', 0, 0),
(307, 'Computer Reviews', 'IAB19-10', '', 'IAB19', 0, 0),
(308, 'Data Centers', 'IAB19-11', '', 'IAB19', 0, 0),
(309, 'Databases', 'IAB19-12', '', 'IAB19', 0, 0),
(310, 'Desktop Publishing', 'IAB19-13', '', 'IAB19', 0, 0),
(311, 'Desktop Video', 'IAB19-14', '', 'IAB19', 0, 0),
(312, 'Email', 'IAB19-15', '', 'IAB19', 0, 0),
(313, 'Graphics Software', 'IAB19-16', '', 'IAB19', 0, 0),
(314, 'Home Video/DVD', 'IAB19-17', '', 'IAB19', 0, 0),
(315, 'Internet Technology', 'IAB19-18', '', 'IAB19', 0, 0),
(316, 'Java', 'IAB19-19', '', 'IAB19', 0, 0),
(317, 'JavaScript', 'IAB19-20', '', 'IAB19', 0, 0),
(318, 'Mac Support', 'IAB19-21', '', 'IAB19', 0, 0),
(319, 'MP3/MIDI', 'IAB19-22', '', 'IAB19', 0, 0),
(320, 'Net Conferencing', 'IAB19-23', '', 'IAB19', 0, 0),
(321, 'Net for Beginners', 'IAB19-24', '', 'IAB19', 0, 0),
(322, 'Network Security', 'IAB19-25', '', 'IAB19', 0, 0),
(323, 'Palmtops/PDAs', 'IAB19-26', '', 'IAB19', 0, 0),
(324, 'PC Support', 'IAB19-27', '', 'IAB19', 0, 0),
(325, 'Portable', 'IAB19-28', '', 'IAB19', 0, 0),
(326, 'Entertainment', 'IAB19-29', '', 'IAB19', 0, 0),
(327, 'Shareware/Freeware', 'IAB19-30', '', 'IAB19', 0, 0),
(328, 'Unix', 'IAB19-31', '', 'IAB19', 0, 0),
(329, 'Visual Basic', 'IAB19-32', '', 'IAB19', 0, 0),
(330, 'Web Clip Art', 'IAB19-33', '', 'IAB19', 0, 0),
(331, 'Web Design/HTML', 'IAB19-34', '', 'IAB19', 0, 0),
(332, 'Web Search', 'IAB19-35', '', 'IAB19', 0, 0),
(333, 'Windows', 'IAB19-36', '', 'IAB19', 0, 0),
(334, 'Travel', 'IAB20', '', '0', 0, 0),
(335, 'Adventure Travel', 'IAB20-1', '', 'IAB20', 0, 0),
(336, 'Africa', 'IAB20-2', '', 'IAB20', 0, 0),
(337, 'Air Travel', 'IAB20-3', '', 'IAB20', 0, 0),
(338, 'Australia & New Zealand', 'IAB20-4', '', 'IAB20', 0, 0),
(339, 'Bed & Breakfasts', 'IAB20-5', '', 'IAB20', 0, 0),
(340, 'Budget Travel', 'IAB20-6', '', 'IAB20', 0, 0),
(341, 'Business Travel', 'IAB20-7', '', 'IAB20', 0, 0),
(342, 'By US Locale', 'IAB20-8', '', 'IAB20', 0, 0),
(343, 'Camping', 'IAB20-9', '', 'IAB20', 0, 0),
(344, 'Canada', 'IAB20-10', '', 'IAB20', 0, 0),
(345, 'Caribbean', 'IAB20-11', '', 'IAB20', 0, 0),
(346, 'Cruises', 'IAB20-12', '', 'IAB20', 0, 0),
(347, 'Eastern Europe', 'IAB20-13', '', 'IAB20', 0, 0),
(348, 'Europe', 'IAB20-14', '', 'IAB20', 0, 0),
(349, 'France', 'IAB20-15', '', 'IAB20', 0, 0),
(350, 'Greece', 'IAB20-16', '', 'IAB20', 0, 0),
(351, 'Honeymoons/Getaways', 'IAB20-17', '', 'IAB20', 0, 0),
(352, 'Hotels', 'IAB20-18', '', 'IAB20', 0, 0),
(353, 'Italy', 'IAB20-19', '', 'IAB20', 0, 0),
(354, 'Japan', 'IAB20-20', '', 'IAB20', 0, 0),
(355, 'Mexico & Central America', 'IAB20-21', '', 'IAB20', 0, 0),
(356, 'National Parks', 'IAB20-22', '', 'IAB20', 0, 0),
(357, 'South America', 'IAB20-23', '', 'IAB20', 0, 0),
(358, 'Spas', 'IAB20-24', '', 'IAB20', 0, 0),
(359, 'Theme Parks', 'IAB20-25', '', 'IAB20', 0, 0),
(360, 'Traveling with Kids', 'IAB20-26', '', 'IAB20', 0, 0),
(361, 'United Kingdom', 'IAB20-27', '', 'IAB20', 0, 0),
(362, 'Real Estate', 'IAB21', '', '0', 0, 0),
(363, 'Apartments', 'IAB21-1', '', 'IAB21', 0, 0),
(364, 'Architects', 'IAB21-2', '', 'IAB21', 0, 0),
(365, 'Buying/Selling Homes', 'IAB21-3', '', 'IAB21', 0, 0),
(366, 'Shopping', 'IAB22', '', '0', 0, 0),
(367, 'Contests & Freebies', 'IAB22-1', '', 'IAB22', 0, 0),
(368, 'Couponing', 'IAB22-2', '', 'IAB22', 0, 0),
(369, 'Comparison', 'IAB22-3', '', 'IAB22', 0, 0),
(370, 'Engines', 'IAB22-4', '', 'IAB22', 0, 0),
(371, 'Religion & Spirituality', 'IAB23', '', '0', 0, 0),
(372, 'Alternative Religions', 'IAB23-1', '', 'IAB23', 0, 0),
(373, 'Atheism/Agnosticism', 'IAB23-2', '', 'IAB23', 0, 0),
(374, 'Buddhism', 'IAB23-3', '', 'IAB23', 0, 0),
(375, 'Catholicism', 'IAB23-4', '', 'IAB23', 0, 0),
(376, 'Christianity', 'IAB23-5', '', 'IAB23', 0, 0),
(377, 'Hinduism', 'IAB23-6', '', 'IAB23', 0, 0),
(378, 'Islam', 'IAB23-7', '', 'IAB23', 0, 0),
(379, 'Judaism', 'IAB23-8', '', 'IAB23', 0, 0),
(380, 'Latter-Day Saints', 'IAB23-9', '', 'IAB23', 0, 0),
(381, 'Pagan/Wiccan', 'IAB23-10', '', 'IAB23', 0, 0),
(382, 'Uncategorized', 'IAB24', '', '0', 0, 0),
(383, 'Non-Standard Content', 'IAB25', '', '0', 0, 0),
(384, 'Unmoderated UGC', 'IAB25-1', '', 'IAB25', 0, 0),
(385, 'Extreme Graphic/Explicit Violence', 'IAB25-2', '', 'IAB25', 0, 0),
(386, 'Pornography', 'IAB25-3', '', 'IAB25', 0, 0),
(387, 'Profane Content', 'IAB25-4', '', 'IAB25', 0, 0),
(388, 'Hate Content', 'IAB25-5', '', 'IAB25', 0, 0),
(389, 'Under Construction', 'IAB25-6', '', 'IAB25', 0, 0),
(390, 'Incentivized', 'IAB25-7', '', 'IAB25', 0, 0),
(391, 'Illegal Content', 'IAB26', '', '0', 0, 0),
(392, 'Illegal Content', 'IAB26-1', '', 'IAB26', 0, 0),
(393, 'Warez', 'IAB26-2', '', 'IAB26', 0, 0),
(394, 'Spyware/Malware', 'IAB26-3', '', 'IAB26', 0, 0),
(395, 'CopyrightInfringement', 'IAB26-4', '', 'IAB26', 0, 0);



CREATE TABLE mediation_networks_param (
  id SERIAL PRIMARY KEY,
  network_id INTEGER NOT NULL,
  parameter_name VARCHAR(100) NOT NULL,
  is_custom SMALLINT NOT NULL DEFAULT 0 -- 0-no, 1-yes
);

-- Ensure network_id references mediation_networks (if applicable)
-- ALTER TABLE mediation_networks_param 
-- ADD CONSTRAINT fk_network FOREIGN KEY (network_id) REFERENCES mediation_networks(network_id) ON DELETE CASCADE;


CREATE TABLE mediation_app_category_assoc (
    assoc_id SERIAL PRIMARY KEY,
    appid INTEGER NOT NULL,
    category_id1 VARCHAR(200) NOT NULL
);



CREATE TABLE mediation_app_adunit_details (
    id SERIAL PRIMARY KEY,
    adunit_id INTEGER NOT NULL,
    adunit_name VARCHAR(50) NOT NULL,
    device_type VARCHAR(50) NOT NULL,
    ad_format INTEGER NOT NULL,  -- 0-banner, 1-medium, 2-fullscreen, etc.
    hourly_impression INTEGER DEFAULT NULL,
    daily_impression INTEGER DEFAULT NULL,
    refresh_interval INTEGER DEFAULT NULL,
    layout_type VARCHAR(50) DEFAULT NULL,
    native_place_ads INTEGER DEFAULT NULL,
    native_ad_position VARCHAR(50) DEFAULT NULL,
    callback_url VARCHAR(50) DEFAULT NULL,
    width INTEGER DEFAULT NULL,
    height INTEGER DEFAULT NULL,
    app_id INTEGER NOT NULL,
    affiliateid INTEGER NOT NULL,
    is_deleted BOOLEAN NOT NULL DEFAULT FALSE, -- true = deleted, false = not deleted
    is_afterplace_nat_ad BOOLEAN DEFAULT FALSE, -- true = yes, false = no
    added_date TIMESTAMP NOT NULL,
    updated_date TIMESTAMP NOT NULL,
    dj_mobile_ad_type VARCHAR(16) NOT NULL,
    dj_zone_type VARCHAR(20) NOT NULL
);



-- Add new columns to the 'rv_zones' table
ALTER TABLE rv_zones
  ADD COLUMN delivery_type INTEGER NOT NULL,
  ADD COLUMN adsize TEXT NOT NULL,
  ADD COLUMN position VARCHAR(100) NOT NULL,
  ADD COLUMN layout VARCHAR(50) NOT NULL,
  ADD COLUMN reward VARCHAR(50) NOT NULL,
  ADD COLUMN amount VARCHAR(50) NOT NULL;



-- Create the table `mediation_app_detail` in PostgreSQL
CREATE TABLE mediation_app_detail (
  appid SERIAL PRIMARY KEY,  -- SERIAL automatically handles AUTO_INCREMENT
  account_id INTEGER NOT NULL,
  platform_type SMALLINT NOT NULL,  -- Smallint is used for tinyint equivalent
  app_name VARCHAR(50) NOT NULL,
  package_name VARCHAR(100),
  app_category1 TEXT NOT NULL,
  icon_image VARCHAR(50) NOT NULL,
  icon_image_width SMALLINT NOT NULL,
  icon_image_height SMALLINT NOT NULL,
  app_added_date TIMESTAMP NOT NULL,  -- PostgreSQL uses TIMESTAMP for datetime
  is_deleted SMALLINT NOT NULL DEFAULT 0,  -- Tinyint is equivalent to SMALLINT in PostgreSQL
  updated_date TIMESTAMP NOT NULL
);




-- Create the table `mediation_net_zone_paramater` in PostgreSQL
CREATE TABLE mediation_net_zone_paramater (
  id BIGINT PRIMARY KEY,  -- BIGINT for large integers; no need for AUTO_INCREMENT
  network_id BIGINT NOT NULL,
  zone_id BIGINT NOT NULL,
  parameter_id SMALLINT NOT NULL,  -- SMALLINT is used for smallint(10) in MySQL
  parameter_value TEXT NOT NULL,  -- TEXT in PostgreSQL is the same as LONGTEXT in MySQL
  account_id INTEGER NOT NULL,  -- INTEGER for int(10) in PostgreSQL
  networks TEXT,  -- TEXT for variable-length string (like in MySQL)
  networks_details TEXT,  -- TEXT for variable-length string
  network_name TEXT NOT NULL,  -- TEXT for variable-length string
  parameter_name TEXT NOT NULL  -- TEXT for variable-length string
);




CREATE TABLE rv_dj_admin_configuration (
  SDK_Androidpath TEXT NOT NULL,
  SDK_IOSpath TEXT NOT NULL,
  API_url TEXT NOT NULL,
  advertiser_id VARCHAR(5) NOT NULL
);
