<?php

/*
+---------------------------------------------------------------------------+
| Revive Adserver                                                           |
| http://www.revive-adserver.com                                            |
|                                                                           |
| Copyright: See the COPYRIGHT.txt file.                                    |
| License: GPLv2 or later, see the LICENSE.txt file.                        |
+---------------------------------------------------------------------------+
*/

// Require the initialisation file
require_once '../../init.php';

// Required files
require_once MAX_PATH . '/lib/OA/Dal.php';
require_once MAX_PATH . '/www/admin/config.php';
require_once MAX_PATH . '/www/admin/lib-statistics.inc.php';
require_once MAX_PATH . '/www/admin/lib-zones.inc.php';
require_once MAX_PATH . '/www/admin/lib-size.inc.php';
require_once MAX_PATH . '/lib/max/Admin_DA.php';
require_once MAX_PATH . '/lib/max/other/html.php';
require_once MAX_PATH . '/lib/OA/Admin/UI/component/Form.php';
require_once MAX_PATH . '/lib/OA/Admin/NumberFormat.php';

if ($GLOBALS['_MAX']['CONF']['database']['type'] == 'pgsql') {
    require_once MAX_PATH . '/lib/OA/Dal/Delivery/pgsql.php';
} else if ($GLOBALS['_MAX']['CONF']['database']['type'] == 'mysqli') {
    require_once MAX_PATH . '/lib/OA/Dal/Delivery/mysqli.php';
}
define("OX_ZoneRewardVideo", 8);
define("OX_ZoneNativeVideo", 9);
define("OX_ZoneInterstitialVideo", 10);
define("OX_ZoneNativeImage", 11);

$table_prefix = $GLOBALS['_MAX']['CONF']['table']['prefix'];
// Register input variables
phpAds_registerGlobalUnslashed(
    'zonename',
    'description',
    'delivery',
    'sizetype',
    'size',
    'width',
    'height',
    'delivery_type',
    'adsize',
    'submit',
    /***********SDK Mediation Start*************/
    'reward',
    'amount',
    'natimg_interval',
    'natimg_position',
    'adposition',
    'adinterval',
    /***********SDK Mediation End*************/
    'comments'
);

/*-------------------------------------------------------*/
/* Affiliate interface security                          */
/*-------------------------------------------------------*/

OA_Permission::enforceAccount(OA_ACCOUNT_MANAGER, OA_ACCOUNT_TRAFFICKER);
OA_Permission::enforceAccessToObject('affiliates', $affiliateid);
OA_Permission::enforceAccessToObject('zones', $zoneid, true);

if (OA_Permission::isAccount(OA_ACCOUNT_TRAFFICKER)) {
    if (!empty($zoneid)) {
        OA_Permission::enforceAllowed(OA_PERM_ZONE_EDIT);
    } else {
        OA_Permission::enforceAllowed(OA_PERM_ZONE_ADD);
    }
}

/*-------------------------------------------------------*/
/* Store preferences									 */
/*-------------------------------------------------------*/
$session['prefs']['inventory_entities'][OA_Permission::getEntityId()]['affiliateid'] = $affiliateid;
phpAds_SessionDataStore();

/*-------------------------------------------------------*/
/* Initialise data                                       */
/*-------------------------------------------------------*/
if (!empty($zoneid)) {
    $doZones = OA_Dal::factoryDO('zones');
    $doZones->zoneid = $zoneid;
    if ($doZones->find() && $doZones->fetch()) {
        $zone = $doZones->toArray();
    }

    if ($zone['width'] == -1) {
        $zone['width'] = '*';
    }
    if ($zone['height'] == -1) {
        $zone['height'] = '*';
    }
} else {
    $doAffiliates = OA_Dal::factoryDO('affiliates');
    $doAffiliates->affiliateid = $affiliateid;

    if ($doAffiliates->find() && $doAffiliates->fetch() && $affiliate = $doAffiliates->toArray()) {
        $zone["zonename"] = $affiliate['name'] . ' - ';
    } else {
        $zone["zonename"] = '';
    }

    $zone['zonename'] .= $GLOBALS['strDefault'];
    $zone['description'] = '';
    $zone['width'] = '468';
    $zone['height'] = '60';
    $zone['delivery'] = phpAds_ZoneBanner;
    $zone['comments'] = null;

    /***********SDK Mediation Start*************/
    $zone['reward'] = '';
    $zone['amount'] = '';
    $zone['adposition'] = '';
    $zone['adinterval'] = '';
    $zone['natimg_interval'] = '';
    $zone['natimg_position'] = '';
    /***********SDK Mediation End*************/
}
$zone['affiliateid'] = $affiliateid;

/***********SDK Mediation Start*************/
$table_prefix = $GLOBALS['_MAX']['CONF']['table']['prefix'];

$affQry = OA_Dal_Delivery_fetchAssoc(OA_Dal_Delivery_query("SELECT af.affiliate_type, af.is_mediation, af.comments, af.account_id, me.appid FROM {$table_prefix}affiliates af LEFT JOIN mediation_app_detail me ON me.account_id = af.account_id WHERE affiliateid = {$affiliateid}"));
$zone['is_mediation'] = $affQry['is_mediation'];
$zone['ad_type'] = $affQry['affiliate_type'];

$aff_filed = unserialize($affQry['comments']);
$zone['app_type'] = $aff_filed['app_type'];
$zone['app_name'] = $aff_filed['app_name'];
$zone['account_id'] = $affQry['account_id'];
$zone['appid'] = $affQry['appid'];
// /***********SDK Mediation End*************/


/*-------------------------------------------------------*/
/* MAIN REQUEST PROCESSING                               */
/*-------------------------------------------------------*/
//build form
$zoneForm = buildZoneForm($zone, $oComponent);

if ($zoneForm->validate()) {
    //process submitted values
    $errors = processForm($zoneForm, $oComponent);

    if (!empty($errors)) {
    }
}
//display the page - show any validation errors that may have occurred
displayPage($zone, $zoneForm, $errors);


/*-------------------------------------------------------*/
/* Build form                                            */
/*-------------------------------------------------------*/
function buildZoneForm($zone, $oComponent = null)
{
    global $conf;
    $newZone = empty($zone['zoneid']);

    $form = new OA_Admin_UI_Component_Form("zoneform", "POST", $_SERVER['SCRIPT_NAME']);
    $form->forceClientValidation(true);
    $form->addElement('hidden', 'zoneid', $zone['zoneid']);
    $form->addElement('hidden', 'affiliateid', $zone['affiliateid']);

    $form->addElement('hidden', 'ad_type', $zone['ad_type']);
    $form->addElement('hidden', 'is_mediation', $zone['is_mediation']);
    $form->addElement('hidden', 'device_type', $zone['app_type']);
    $form->addElement('hidden', 'account_id', $zone['account_id']);
    $form->addElement('hidden', 'appid', $zone['appid']);

    $form->addElement('header', 'zone_basic_info', $GLOBALS['strBasicInformation']);
    $form->addElement('text', 'zonename', $GLOBALS['strName']);
    $form->addElement('text', 'description', $GLOBALS['strDescription']);

    //zone type group
    $zoneTypes[] = $form->createElement(
        'radio',
        'delivery',
        '',
        "<img src='" . OX::assetPath() . "/images/icon-zone.gif' align='absmiddle'>&nbsp;" . $GLOBALS['strBannerButtonRectangle'],
        phpAds_ZoneBanner,
        array(
            'id' => 'delivery-b',
            'onClick' => 'phpAds_formEnableSize();',
            'onChange' => 'oa_hide("warning_change_zone_type");'
        )
    );

    //ReviveAdservermod.com NativeAds Custom Work Start
    $zoneTypes[] = $form->createElement(
        'radio',
        'delivery',
        '',
        "<img src='" . OX::assetPath() . "/images/icon-zone.gif' align='absmiddle'>&nbsp;Native Ads",
        OX_ZoneNativeImage,
        array(
            'id' => 'delivery-N',
            'onClick' => 'phpAds_formEnableSize();',
            'onChange' => 'oa_hide("warning_change_zone_type");'
        )
    );
    //ReviveAdservermod.com NativeAds Custom Work End
    if ($conf['oxInvocationTags']['isAllowedAdlayer'] || $zone['delivery'] == phpAds_ZoneInterstitial) {
        $zoneTypes[] = $form->createElement(
            'radio',
            'delivery',
            '',
            "<img src='" . OX::assetPath() . "/images/icon-interstitial.gif' align='absmiddle'>&nbsp;" . $GLOBALS['strInterstitial'],
            phpAds_ZoneInterstitial,
            array(
                'id' => 'delivery-i',
                'onClick' => 'phpAds_formEnableSize();',
                'onChange' => 'oa_hide("warning_change_zone_type");'
            )
        );
    }
    if ($conf['oxInvocationTags']['isAllowedPopup'] || $zone['delivery'] == phpAds_ZonePopup) {
        $zoneTypes[] = $form->createElement(
            'radio',
            'delivery',
            '',
            "<img src='" . OX::assetPath() . "/images/icon-popup.gif' align='absmiddle'>&nbsp;" . $GLOBALS['strPopup'],
            phpAds_ZonePopup,
            array(
                'id' => 'delivery-p',
                'onClick' => 'phpAds_formEnableSize();',
                'onChange' => 'oa_hide("warning_change_zone_type");'
            )
        );
    }
    if ($zone['ad_type'] == 2) {
        $zoneTypes[] = $form->createElement(
            'radio',
            'delivery',
            '',
            "<img src='" . OX::assetPath() . "/images/icon-textzone.gif' align='absmiddle'>&nbsp;" . $GLOBALS['strTextAdZone'],
            phpAds_ZoneText,
            array(
                'id' => 'delivery-t',
                'onClick' => 'phpAds_formDisableSize();',
                'onChange' => 'oa_hide("warning_change_zone_type");'
            )
        );
    }
    if ($zone['ad_type'] == 2) {
        $zoneTypes[] = $form->createElement(
            'radio',
            'delivery',
            '',
            "<img src='" . OX::assetPath() . "/images/icon-zone-email.gif' align='absmiddle'>&nbsp;" . $GLOBALS['strEmailAdZone'],
            MAX_ZoneEmail,
            array(
                'id' => 'delivery-e',
                'onClick' => 'phpAds_formEnableSize();',
                'onChange' => 'oa_hide("warning_change_zone_type");'
            )
        );
    }
    if (!empty($conf['allowedBanners']['video'])) {


        if ($zone['ad_type'] == 2) {

            $zoneTypes[] = $form->createElement(
                'radio',
                'delivery',
                '',
                "<img src='" . OX::assetPath() . "/images/icon-zone-video-instream.png' align='absmiddle'>&nbsp;" . $GLOBALS['strZoneVideoInstream'],
                OX_ZoneVideoInstream,
                array(
                    'id' => 'delivery-vi',
                    'onClick' => 'phpAds_formDisableSize();',
                    'onChange' => 'oa_hide("warning_change_zone_type");'
                )
            );
            $zoneTypes[] = $form->createElement(
                'radio',
                'delivery',
                '',
                "<img src='" . OX::assetPath() . "/images/icon-zone-video-overlay.png' align='absmiddle'>&nbsp;" . $GLOBALS['strZoneVideoOverlay'],
                OX_ZoneVideoOverlay,
                array(
                    'id' => 'delivery-vo',
                    'onClick' => 'phpAds_formDisableSize();',
                    'onChange' => 'oa_hide("warning_change_zone_type");'
                )
            );
        }

        //App Ad Type - Custom Work

        $show = 'radio';
        $inter_string = 'Native Video';

        if ($zone['ad_type'] == 1 || $zone['ad_type'] == 3) {


            $zoneTypes['del_inter'] = $form->createElement(
                'radio',
                'delivery',
                '',
                "<img src='" . OX::assetPath() . "/images/icon-zone-video-instream.png' align='absmiddle'>&nbsp;" . 'Interstitial Video',
                OX_ZoneInterstitialVideo,
                array(
                    'id' => 'delivery-inter',
                    'onClick' => 'phpAds_formDisableSize()();',
                    'onChange' => 'oa_hide("warning_change_zone_type");'
                )
            );



            $zoneTypes['del_reward'] = $form->createElement(
                'radio',
                'delivery',
                '',
                "<img src='" . OX::assetPath() . "/images/icon-zone-video-overlay.png' align='absmiddle'>&nbsp;" . 'Rewarded Video',
                OX_ZoneRewardVideo,
                array(
                    'id' => 'delivery-rv',
                    'onClick' => 'phpAds_formDisableSize()();',
                    'onChange' => 'oa_hide("warning_change_zone_type");'
                )
            );

        }
    }


    $aDefaultSizes['text1'] = $form->createElement(
        'text',
        'reward[0]',
        null,
        array('id' => 'rvpoint_0', 'placeholder' => 'Reward')
    );

    $aDefaultSizes['text'] = $form->createElement('text', 'amount[0]', null, array('id' => 'rvamount_0', 'placeholder' => 'Amount'));

    $aDefaultSizesnative['textpos'] = $form->createElement(
        'text',
        'adposition',
        null,
        array('id' => 'nativepos', 'placeholder' => '1,2,3', 'class' => 'medium'),
        "<br/>"
    );

    $aDefaultSizesnativeads['textads'] = $form->createElement(
        'text',
        'adinterval',
        null,
        array('id' => 'nativeads', 'placeholder' => 'Enter Ads Interval', 'class' => 'medium'),
        "<br/>"
    );

    $aDefaultNatImg['textpos'] = $form->createElement(
        'text',
        'natimg_position',
        null,
        array('id' => 'natimg_position', 'placeholder' => '1,2,3', 'class' => 'medium'),
        "<br/>"
    );

    $aDefaultNatInterval['textads'] = $form->createElement(
        'text',
        'natimg_interval',
        null,
        array('id' => 'natimg_interval', 'placeholder' => 'Enter Ads Interval', 'class' => 'medium'),
        "<br/>"
    );

    $rewardadd['addreward'] = $form->addElement('button', 'add_reward', 'Add Reward', array('id' => 'rvaddrw'));
    $rewardadd['delreward'] = $form->addElement('button', 'del_reward', 'Delete Reward', array('id' => 'rvdelrw'));


    $form->addGroup($zoneTypes, 'zone_types', $GLOBALS['strZoneType'], "<br/>");
    //ReviveAdservermod.com Native Ads custom Code Start
    $table_prefix = $GLOBALS['_MAX']['CONF']['table']['prefix'];

    $sel_adsize = unserialize($zone['adsize']);

    $list = array('1' => 'Small', '2' => 'Medium', '3' => 'Customized');

    $input_adlist = '';




    for ($i = 1; $i <= count($list); $i++) {


        $checked = '';
        if ($sel_adsize) {
            if (in_array($i, $sel_adsize)) {

                $checked = 'checked';
            }
        }
        $input_adlist .= '<tr width:250px!important class="ads_list">
                <td>
                  <label>
                      <input  name=adsize[] type="checkbox" value=' . $i . ' class="adss-list" id="adlistid' . $i . '" ' . $checked . ' >' . $list[$i] . '
                  </label>
                </td></tr>';
    }
    // $form->addGroup($dspgroup, 'dsp_type', 'DSP' );
    $adsize['ads'] = $form->createElement('html', 'ads', '<span style="display:-webkit-box;">

            <div class="deal-dsps" style="margin-right: 25px;  overflow: auto;">
              <div id="zones-linked-container">
                <table id="adsize_list" class="adsize_class">
    
                  <thead>
                    <tr class="header hide" style="display: table-row;">
                  
                    </tr>
                  </thead>
                  <tbody>
                    <tr class="ad_lists">
                      <td>
                        <label>
                            ' . $input_adlist . '
                        </label>
                      </td>
                    </tr>
                  </tbody>
                </table>
              </div>
        </div>');

    $form->addGroup($adsize, 'adsize', 'AdSize');











    //ReviveAdservermod.com Native Ads custom Code End

    $form->addGroup($aDefaultSizesnative, '', 'Ad Positions', array('id' => 'adpositions'), "<br/>");
    $form->addGroup($aDefaultSizesnativeads, '', ' ', array('id' => 'adpositionsnative'), "<br/>");

    $form->addGroup($aDefaultNatImg, '', 'Ad Positions', array('id' => 'adpositions'), "<br/>");
    $form->addGroup($aDefaultNatInterval, '', ' ', array('id' => 'adpositionsnative'), "<br/>");

    $layoutsize = array('landscape' => 'landscape', 'portrait' => 'portrait');

    foreach ($layoutsize as $id => $value) {
        $arraylayoutsize[$id] = $value;
    }

    $form->addElement('select', 'layout', 'Layout', $arraylayoutsize);

    $form->addGroup($aDefaultSizes, 'rv_video', 'Rewards', array('id' => 'rvgroup', 'class' => 'medium'));


    $position = array('portrait' => 'portrait', 'landscape' => 'landscape');

    foreach ($position as $id => $value) {
        $position[$id] = $value;
    }

    $pos_element = $form->createElement('select', 'position', 'Select Video Position', $position);
    $pos_element->setAttribute('id', 'position');

    $apptype = array('android' => 'android', 'ios' => 'ios');

    foreach ($apptype as $id => $value) {
        $arrayapptype[$id] = $value;
    }
    $table_prefix = $GLOBALS['_MAX']['CONF']['table']['prefix'];
    $queryN = OA_Dal_Delivery_query("SELECT * FROM {$table_prefix}affiliates WHERE affiliateid =  " . $zone['affiliateid']);
    $Value = OA_Dal_Delivery_fetchAssoc($queryN);
    $network_id = $Value['network_id'] ? $Value['network_id'] : 0;

    $networkName = '';
    if (!empty($network_id)) {
        $Network = OA_Dal_Delivery_query("SELECT * FROM mediation_networks WHERE network_id =  " . $network_id);
        $Value1 = OA_Dal_Delivery_fetchAssoc($Network);
        $networkName = $Value1['network_name'] ? $Value1['network_name'] : '';
    }



    //size
    global $phpAds_IAB;
    switch ($zone['delivery']) {
        case phpAds_ZoneText:
        case OX_ZoneVideoInstream:
        case OX_ZoneVideoOverlay:
        case OX_ZoneInterstitialVideo:
        case OX_ZoneRewardVideo:
        case OX_ZoneNativeVideo:
            $sizeDisabled = true;
            $zone['width'] = '*';
            $zone['height'] = '*';
            break;
        default:
            $sizeDisabled = false;
            break;

    }

    $aDefaultSize['radio'] = $form->createElement(
        'radio',
        'sizetype',
        '',
        '',
        'default',
        ['id' => 'size-d']
    );
    foreach (array_keys($phpAds_IAB) as $key) {
        $iabSizes[$phpAds_IAB[$key]['width'] . "x" . $phpAds_IAB[$key]['height']] =
            $GLOBALS['strIab'][$key];
    }
    $iabSizes['-'] = $GLOBALS['strCustom'];
    $aDefaultSize['select'] = $form->createElement(
        'select',
        'size',
        null,
        $iabSizes,
        ['onchange' => 'phpAds_formSelectSize(this); oa_sizeChangeUpdateMessage("warning_change_zone_size");', 'class' => 'medium']
    );


    $aCustomSize['radio'] = $form->createElement(
        'radio',
        'sizetype',
        '',
        '',
        'custom',
        ['id' => 'size-c']
    );

    $aCustomSize['width'] = $form->createElement(
        'text',
        'width',
        $GLOBALS['strWidth'] . ':',
        [
            'onkeydown' => 'phpAds_formEditSize();',
            'onChange' => 'oa_sizeChangeUpdateMessage("warning_change_zone_size");'
        ]
    );
    $aCustomSize['width']->setSize(5);
    $aCustomSize['height'] = $form->createElement(
        'text',
        'height',
        $GLOBALS['strHeight'] . ':',
        [
            'onkeydown' => 'phpAds_formEditSize();',
            'onChange' => 'oa_sizeChangeUpdateMessage("warning_change_zone_size");'
        ]
    );
    $aCustomSize['height']->setSize(5);

    $sizeTypes['default'] = $form->createElement('group', 'defaultSizeG', null, $aDefaultSize, null, false);
    $sizeTypes['custom'] = $form->createElement('group', 'customSizeG', null, $aCustomSize, null, false);

    //disable fields if necessary
    if ($sizeDisabled) {
        $aDefaultSize['radio']->setAttribute('disabled', $sizeDisabled);
        $aDefaultSize['select']->setAttribute('disabled', $sizeDisabled);
        $aCustomSize['radio']->setAttribute('disabled', $sizeDisabled);
        $aCustomSize['width']->setAttribute('disabled', $sizeDisabled);
        $aCustomSize['height']->setAttribute('disabled', $sizeDisabled);
    }

    $form->addGroup($sizeTypes, 'size_types', $GLOBALS['strSize'], "<br/>");
    /** CUSTOM  TYPE START **/

    $deliveryTypes[] = $form->createElement(
        'radio',
        'delivery_type',
        '',
        "Internal",
        '1'
    );



    $deliveryTypes[] = $form->createElement(
        'radio',
        'delivery_type',
        '',
        "External",
        '2'
    );


    $form->addGroup($deliveryTypes, 'delivery', 'Delivery', "<br/>");

    /** CUSTOM  TYPE END **/
    $form->addElement('textarea', 'comments', $GLOBALS['strComments']);

    if ($oComponent && method_exists($oComponent, 'extendZoneForm')) {
        $oComponent->extendZoneForm($form, $zone, $newZone);
    }

    $form->addElement('controls', 'form-controls');
    $form->addElement('submit', 'submit', $GLOBALS['strSaveChanges']);


    //validation rules
    $translation = new OX_Translation();
    $urlRequiredMsg = $translation->translate($GLOBALS['strXRequiredField'], [$GLOBALS['strName']]);
    $form->addRule('zonename', $urlRequiredMsg, 'required');

    $reward = explode("|", $zone['reward']);
    $amount = explode("|", $zone['amount']);
    $count_reward = (empty($zone['reward']) ? '0' : count($reward));

    $php_array = $reward;
    $reward_array = json_encode($php_array);

    $php_array1 = $amount;
    $amount_array = json_encode($php_array1);

    $reward_array = explode("|", $zone['reward']);
    $amount_array = explode("|", $zone['amount']);
    $count_reward = (empty($zone['reward']) ? '0' : count($reward_array));

    if ($newZone) {
        $zone['delivery_type'] = 1;
    }
    $form->addElement('html', 'jsForZoneForm', "
    <script src='https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js'></script>
	<script>
	var jq = $.noConflict(true);
	var is_mediation = '" . $zone['is_mediation'] . "';

	var count = 1;
	var i = 0;
	var db_value = '" . $count_reward . "' - 1;
	var db_value_count = '" . $count_reward . "';
	var ad_type = '" . $zone['ad_type'] . "';
	if(db_value_count != '') {
		for(var j = 0; j < db_value; j++) {
			var a = '<tr id= added_' + count + '><td width=30></td><td width=170 valign=top style=padding-top: 5px></td>&nbsp;<td width=100%><input name=reward[' + count + '] type=text id=rvpoint_' + count + ' placeholder=Reward class=x-small>&nbsp;<input name=amount[' + count + '] type=text id=rvamount_' + count + ' placeholder=Amount class=x-small>&nbsp;</td></tr>';
			jq('#rvamount_' + j).after(a);
			count++;
		}
		count = db_value_count;
		i = db_value;
	}
	if(ad_type == 1 || ad_type == 3) {
       
        $('label[for=delivery-inter],#delivery-inter').show();
     
		$('label[for=delivery-rv],#delivery-rv').show();
		$('label[for=delivery-native],#delivery-native').show();
	} else {

		$('label[for=delivery-inter],#delivery-inter').hide();
		$('label[for=delivery-rv],#delivery-rv').hide();
		$('label[for=delivery-native],#delivery-native').hide();
	}
	jq('#nativepos').before('<td>To place position controls, you must use the ad pacer code when integrating  SDK.<br>Note : the position in your current streaming is zero(0).<br><br>place ads in these positions<br></td>');
	jq('#nativeads').before('<td>After placed  ads show ads every </td>');
	jq('#rvaddrw').on('click', function() {
		var a = '<tr id=added_' + count + '><td width=30></td><td width=170 valign=top style=padding-top: 5px></td>&nbsp;<td width=100%><input name=reward[' + count + '] type=text id=rvpoint_' + count + ' placeholder=Reward class=x-small>&nbsp;<input name=amount[' + count + '] type=text id=rvamount_' + count + ' placeholder=Amount class=x-small>&nbsp;</td></tr>';
		jq('#rvamount_' + i).after(a);
		count++;
		i++;
	});
	jq('#rvdelrw').on('click', function() {
		count--;
		i--;
		$('#added_' + count).remove();
	});
	var reward_array = '" . $zone['reward'] . "';
	var amount_array = '" . $zone['amount'] . "';
	reward_array = reward_array.split('|');
	amount_array = amount_array.split('|');
	$.each(reward_array, function(index, value) {
		$('#rvpoint_' + index).val(value);
	});
	$.each(amount_array, function(index, value) {
		$('#rvamount_' + index).val(value);
	});
	jq(document).ready(function() {
		jq('#mobileapptype').parent().parent().hide();
		jq('#rvamount_0').parent().parent().hide();
		jq('#rvaddrw').parent().parent().hide();
		jq('#position').parent().parent().hide();
		jq('#layout').parent().parent().hide();
		jq('#nativeads').parent().parent().hide();
		jq('#nativepos').parent().parent().hide();
		jq('#natimg_position').parent().parent().hide();
		jq('#natimg_interval').parent().parent().hide();
        jq('#adsize_list').parent().parent().parent().parent().parent().hide();
       
		if(ad_type == 1 || ad_type == 3) {
			jq('#ad_type').val('1');
			if(document.getElementById('delivery-rv').checked == true) {
				jq('#rvamount_0').parent().parent().show();
				jq('#rvaddrw').parent().parent().show();
				jq('#position').parent().parent().show();
				jq('#mobileapptype').parent().parent().show();
				jq('#layout').parent().parent().show();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
			} else if(document.getElementById('delivery-inter').checked == true) {
				jq('#layout').parent().parent().show();
				jq('#mobileapptype').parent().parent().show();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
			}

			else if(document.getElementById('delivery-N').checked == true) {
                jq('#adsize_list').parent().parent().parent().parent().parent().show();
			
            }
             else {
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
			}
		} else {
			jq('#ad_type').val('0');
			jq('#mobileapptype').parent().parent().hide();
			jq('#rvamount_0').parent().parent().hide();
			jq('#rvaddrw').parent().parent().hide();
			jq('#position').parent().parent().hide();
			jq('#layout').parent().parent().hide();
			jq('#nativeads').parent().parent().hide();
			jq('#nativepos').parent().parent().hide();
		}    
		if(ad_type == 1 || ad_type == 3) {
			jq('#ad_type').val('1');
			jq('#mobileapptype').parent().parent().show();
			if(document.getElementById('delivery-rv').checked == true) {
				jq('#rvamount_0').parent().parent().show();
				jq('#rvaddrw').parent().parent().show();
				jq('#position').parent().parent().show();
			} else if(document.getElementById('delivery-inter').checked == true) {
				jq('#layout').parent().parent().show();
            } 
            // else if(document.getElementById('delivery-native').checked == true) {
			// 	jq('#nativeads').parent().parent().show();
			// 	jq('#nativepos').parent().parent().show();
            // }
             else {
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
			}
		} else {
			jq('#ad_type').val('0');
			jq('#mobileapptype').parent().parent().hide();
			jq('#rvamount_0').parent().parent().hide();
			jq('#rvaddrw').parent().parent().hide();
			jq('#position').parent().parent().hide();
			jq('#layout').parent().parent().hide();
			jq('#nativeads').parent().parent().hide();
			jq('#nativepos').parent().parent().hide();
		}
		//~ });         
		jq('input[type=radio][name=delivery]').change(function() {
			// INTERSTITIAL
			if(this.value == 10) {
				if(ad_type == 1 || ad_type == 3) {
					jq('#natimg_interval').parent().parent().hide();
					jq('#natimg_position').parent().parent().hide();
					jq('#mobileapptype').parent().parent().show();
					jq('#rvamount_0').parent().parent().hide();
					jq('#rvaddrw').parent().parent().hide();
					jq('#position').parent().parent().hide();
					jq('#nativepos').parent().parent().hide();
					jq('#nativeads').parent().parent().hide();
					jq('#layout').parent().parent().show();
                    jq('#adsize_list').parent().parent().parent().parent().parent().hide();
				}
			}
			// NATIVE IMAGE
			else if(this.value == 11) {
				if(ad_type == 1 || ad_type == 3) {
					jq('#mobileapptype').parent().parent().show();
					jq('#natimg_interval').parent().parent().hide();
					jq('#natimg_position').parent().parent().hide();
					jq('#rvamount_0').parent().parent().hide();
					jq('#rvaddrw').parent().parent().hide();
					jq('#position').parent().parent().hide();
					jq('#nativepos').parent().parent().hide();
					jq('#nativeads').parent().parent().hide();
					jq('#layout').parent().parent().hide();
                    jq('#adsize_list').parent().parent().parent().parent().parent().hide();
				}
			}
			// REWARDED
			else if(this.value == 8) {
				if(ad_type == 1 || ad_type == 3) {
					jq('#natimg_interval').parent().parent().hide();
					jq('#natimg_position').parent().parent().hide();
					jq('#rvamount_0').parent().parent().show();
					jq('#rvaddrw').parent().parent().show();
					jq('#position').parent().parent().show();
					jq('#layout').parent().parent().show();
					jq('#nativepos').parent().parent().hide();
					jq('#nativeads').parent().parent().hide();
					jq('#mobileapptype').parent().parent().show();
                    jq('#adsize_list').parent().parent().parent().parent().parent().hide();
				}
			}
			// NATIVE
			else if(this.value == 9) {
				if(ad_type == 1 || ad_type == 3) {
					jq('#natimg_interval').parent().parent().hide();
					jq('#natimg_position').parent().parent().hide();
					jq('#nativepos').parent().parent().show();
					jq('#nativeads').parent().parent().show();
					jq('#rvamount_0').parent().parent().hide();
					jq('#layout').parent().parent().hide();
					jq('#rvaddrw').parent().parent().hide();
					jq('#position').parent().parent().hide();
					jq('#mobileapptype').parent().parent().show();
                    jq('#adsize_list').parent().parent().parent().parent().parent().hide();
				}
			} else if(this.value == 0) {
				jq('#natimg_interval').parent().parent().hide();
				jq('#natimg_position').parent().parent().hide();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
                jq('#adsize_list').parent().parent().parent().parent().parent().hide();
			}
			if(this.value == 1) {
				jq('#natimg_interval').parent().parent().hide();
				jq('#natimg_position').parent().parent().hide();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
                jq('#adsize_list').parent().parent().parent().parent().parent().hide();
			} else if(this.value == 3) {
				jq('#natimg_interval').parent().parent().hide();
				jq('#natimg_position').parent().parent().hide();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
                jq('#adsize_list').parent().parent().parent().parent().parent().hide();
			} else if(this.value == 4) {
				jq('#natimg_interval').parent().parent().hide();
				jq('#natimg_position').parent().parent().hide();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
                jq('#adsize_list').parent().parent().parent().parent().parent().hide();
			} else if(this.value == 6) {
				jq('#natimg_interval').parent().parent().hide();
				jq('#natimg_position').parent().parent().hide();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
                jq('#adsize_list').parent().parent().parent().parent().parent().hide();
			} else if(this.value == 7) {
				jq('#natimg_interval').parent().parent().hide();
				jq('#natimg_position').parent().parent().hide();
				jq('#rvamount_0').parent().parent().hide();
				jq('#rvaddrw').parent().parent().hide();
				jq('#position').parent().parent().hide();
				jq('#layout').parent().parent().hide();
				jq('#nativeads').parent().parent().hide();
				jq('#nativepos').parent().parent().hide();
                jq('#adsize_list').parent().parent().parent().parent().parent().hide();
			}
            else if(this.value == 11) {
		
                jq('#adsize_list').parent().parent().parent().parent().parent().show();
			}
		});
	});
	jq(document).ready(function() {
		if(ad_type == 1 || ad_type == 3) {
			jq('#mobileapptype').parent().parent().show();
			$('label[for=delivery-inter],#delivery-inter').show();
			$('label[for=delivery-rv],#delivery-rv').show();
			$('label[for=delivery-native],#delivery-native').show();
		} else {
			jq('#mobileapptype').parent().parent().hide();
			$('label[for=delivery-inter],#delivery-inter').hide();
			$('label[for=delivery-rv],#delivery-rv').hide();
			$('label[for=delivery-native],#delivery-native').hide();
		}
    });

	

	</script>");


    /*
    TODO
    max_formSetRequirements('width', '<?php echo addslashes($strWidth); ?>', true, 'number*');
    max_formSetRequirements('height', '<?php echo addslashes($strHeight); ?>', true, 'number*');
    */

    //set form values
    $form->setDefaults($zone);

    //sizes radio
    if (phpAds_sizeExists($zone['width'], $zone['height'])) {
        $size = $zone['width'] . "x" . $zone['height'];
        $sizeType = 'default';
    } else {
        $size = "-";
        $sizeType = 'custom';
    }
    $form->setDefaults(['size' => $size, 'sizetype' => $sizeType]);


    return $form;
}


/*-------------------------------------------------------*/
/* Process submitted form                                */
/*-------------------------------------------------------*/
/**
 * Processes submit values of zone form
 *
 * @param OA_Admin_UI_Component_Form $form form to process
 * @return An array of Pear::Error objects if any
 */
function processForm($form, $oComponent = null)
{
    $aFields = $form->exportValues();

    switch ($aFields['delivery']) {
        case phpAds_ZoneText:
            $aFields['width'] = $aFields['height'] = 0;
            break;
        case OX_ZoneVideoOverlay:
            $aFields['width'] = $aFields['height'] = -2;
            break;
        case OX_ZoneVideoInstream:
            $aFields['width'] = $aFields['height'] = -3;
            break;
        case OX_ZoneNativeVideo:
            $aFields['width'] = $aFields['height'] = -4;
            break;
        case OX_ZoneInterstitialVideo:
            $aFields['width'] = $aFields['height'] = -5;
            break;
        case OX_ZoneRewardVideo:
            $aFields['width'] = $aFields['height'] = -5;
            break;
        default:
            if ($aFields['sizetype'] == 'custom') {
                if (isset($aFields['width']) && $aFields['width'] == '*') {
                    $aFields['width'] = -1;
                }
                if (isset($aFields['height']) && $aFields['height'] == '*') {
                    $aFields['height'] = -1;
                }
            } else {
                list($aFields['width'], $aFields['height']) = explode('x', $aFields['size']);
            }
            break;
    }

    if (!(is_numeric($aFields['oac_category_id'])) || ($aFields['oac_category_id'] <= 0)) {
        $aFields['oac_category_id'] = 'NULL';
    }


    $ad_format = '';

    //banner button
    if ($aFields['delivery'] == 0) {
        $ad_format = "MED_BAN";
    }
    //rewarded
    if ($aFields['delivery'] == 8) {
        $ad_format = "MED_REW_VI";
    }
    //native
    if ($aFields['delivery'] == 9) {
        $ad_format = "MED_NA";
    }
    //interstitial
    if ($aFields['delivery'] == 10) {
        $ad_format = "MED_FULL_INT";
    }
    //interstitial DHTML
    if ($aFields['delivery'] == 1) {
        $ad_format = "MED_INT_DHTML";
    }

    if (empty($errors)) {

        // Edit
        if (!empty($aFields['zoneid'])) {
            // before we commit any changes to db, store whether the size has changed
            $aZone = Admin_DA::getZone($aFields['zoneid']);
            $size_changed = ($aFields['width'] != $aZone['width'] || $aFields['height'] != $aZone['height']) ? true : false;
            $type_changed = ($aFields['delivery'] != $aZone['type']) ? true : false;

            $doZones = OA_Dal::factoryDO('zones');
            $doZones->zonename = $aFields['zonename'];
            $doZones->description = $aFields['description'];
            $doZones->width = $aFields['width'];
            $doZones->height = $aFields['height'];
            $doZones->comments = $aFields['comments'];
            $doZones->delivery = $aFields['delivery'];

            $doZones->reward = $aFields['reward'];
            $doZones->amount = $aFields['amount'];
            $doZones->layout = $aFields['layout'];

            $doZones->adposition = $aFields['adposition'];
            $doZones->adinterval = $aFields['adinterval'];
            $doZones->natimg_interval = $aFields['natimg_interval'];
            $doZones->natimg_position = $aFields['natimg_position'];
            $doZones->adsize = serialize($_POST['adsize']);

            if ($aFields['delivery'] != phpAds_ZoneText && $aFields['delivery'] != phpAds_ZoneBanner) {
                $doZones->prepend = '';
                $doZones->append = '';
            }

            $doZones->oac_category_id = $aFields['oac_category_id'];
            $doZones->zoneid = $aFields['zoneid'];
            $doZones->update();




            $table_prefix = $GLOBALS['_MAX']['CONF']['table']['prefix'];

            $ad_size = serialize($_POST['adsize']);
            OA_Dal_Delivery_query("UPDATE {$table_prefix}zones SET adsize= '" . $ad_size . "', delivery_type = '" . $aFields['delivery_type'] . "' WHERE zoneid = " . $aFields['zoneid']);

            $affiliates = OA_Dal_Delivery_fetchAssoc(OA_Dal_Delivery_query("SELECT * from {$table_prefix}affiliates where affiliateid='" . $aFields['affiliateid'] . "'"));

            $adunit_det = OA_Dal_Delivery_query("SELECT adunit_id,adunit_name,dj_mobile_ad_type from mediation_app_adunit_details where affiliateid=" . $affiliates['affiliateid']);

            if (OA_Dal_Delivery_numRows($adunit_det) > 0) {
                while ($adunit_list = OA_Dal_Delivery_fetchAssoc($adunit_det)) {
                    $total_parameters = OA_Dal_Delivery_query("SELECT * from mediation_networks_param where network_id ='" . $affiliates['network_id'] . "'");

                    while ($param_list = OA_Dal_Delivery_fetchAssoc($total_parameters)) {

                        $submitKeyExists = "p_" . $adunit_list['adunit_id'] . "_" . $param_list['id'];

                        $_chk = $_POST["p_" . $adunit_list['adunit_id'] . "_" . $param_list['id']];

                        $par_val = OA_Dal_Delivery_query("SELECT * from mediation_net_zone_paramater where network_id=" . $affiliates['network_id'] . " and zone_id=" . $adunit_list['adunit_id'] . " and parameter_id=" . $param_list['id']);
                        $param = trim($_POST["p_" . $adunit_list['adunit_id'] . "_" . $param_list['id']], ' ');
                        if (OA_Dal_Delivery_numRows($par_val) > 0) {
                            if (array_key_exists($submitKeyExists, $_POST)) {
                                if ($_chk != '') {
                                    // print_r();
                                    // exit; 
                                    OA_Dal_Delivery_query("UPDATE `mediation_net_zone_paramater` SET `parameter_value`='" . $param . "' WHERE network_id=" . $affiliates['network_id'] . " and zone_id=" . $adunit_list['adunit_id'] . " and parameter_id=" . $param_list['id']);
                                } else {
                                    OA_Dal_Delivery_query("DELETE FROM `mediation_net_zone_paramater` WHERE network_id=" . $affiliates['network_id'] . " and zone_id=" . $adunit_list['adunit_id'] . " and parameter_id=" . $param_list['id'] . "");

                                }
                            }
                        } else {
                            if ($_chk != '') {

                                OA_Dal_Delivery_query("INSERT INTO `mediation_net_zone_paramater` (network_id,zone_id,parameter_id,parameter_value,account_id) VALUES ('" . $affiliates['network_id'] . "','" . $adunit_list['adunit_id'] . "','" . $param_list['id'] . "','" . $param . "','" . $affiliates['account_id'] . "')");


                            }
                        }
                    }
                }
            }

            $mobileapp = $_POST['mobileapptype'];

            if ($aFields['delivery'] == 7) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "' where zoneid=" . $aFields['zoneid']);
            }
            if ($_POST['delivery'] == 10) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set delivery=10, width='" . $aFields['width'] . "', height='" . $aFields['height'] . "', position='', amount='', reward='', adposition='', adinterval='' WHERE zoneid=" . $aFields['zoneid']);
            }
            if ($aFields['delivery'] == 11) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "' where zoneid=" . $aFields['zoneid']);

                $natimg_position = $_POST['natimg_position'];
                $natimg_interval = $_POST['natimg_interval'];

                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set natimg_position = '" . $natimg_position . "',natimg_interval = '" . $natimg_interval . "',mobileapptype='" . $mobileapp . "' where zoneid =" . $aFields['zoneid']);
            }

            if ($aFields['delivery'] == 3) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "' where zoneid=" . $aFields['zoneid']);
            }

            if ($aFields['delivery'] == 8) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "',position = '" . $aFields['position'] . "' where zoneid=" . $aFields['zoneid']);
                if (isset($aFields['reward']) && isset($aFields['amount'])) {
                    $layoutposition = $_POST['layout'];
                    $reward = implode("|", $_POST['reward']);
                    $amt = implode("|", $_POST['amount']);
                    OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set reward='" . $reward . "',amount='" . $amt . "',layout='" . $layoutposition . "' where zoneid =" . $aFields['zoneid']);
                }
            }

            if ($aFields['delivery'] == 9) {
                $nativepos = $_POST['adposition'];
                $nativeads = $_POST['adinterval'];

                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set adposition='" . $nativepos . "',adinterval='" . $nativeads . "',mobileapptype='" . $mobileapp . "' where zoneid =" . $aFields['zoneid']);
            }

            if ($aFields['delivery'] == 10) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "' where zoneid=" . $aFields['zoneid']);

                $layoutposition = $_POST['layout'];
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set layout='" . $layoutposition . "',reward='',position='',amount='' where zoneid=" . $aFields['zoneid']);
            }

            if ($_POST['app_select'] == 1) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set app_select='" . $_POST['app_select'] . "',mobileapptype='" . $mobileapp . "' where zoneid =" . $aFields['zoneid']);
            }

            if ($_POST['is_mediation'] == 1) {
                $add_adunit_Objs = array(
                    "adunit_id" => $aFields['zoneid'],
                    "adunit_name" => $_POST['zonename'],
                    "device_type" => $_POST['device_type'],
                    "ad_format" => $aFields['delivery'],
                    "refresh_interval" => $_POST['ref_inter_val'],
                    "layout_type" => $_POST['layout'],
                    "native_Place_ads" => $_POST['adinterval'],
                    "native_ad_position" => $_POST['adposition'],
                    "callback_url" => $_POST['call_bk_url'],
                    "is_afterplace_nat_ad" => ($_POST['adinterval'] > 0 ? 1 : 0),
                    "width" => $_POST['width'],
                    "height" => $_POST['height'],
                    "app_id" => $aFields['affiliateid'],
                    "added_date" => date("Y-m-d H:i:s"),
                    "affiliateid" => $aFields['affiliateid'],
                    "dj_mobile_ad_type" => $_POST['mobile_type'],
                    "dj_zone_type" => $ad_format
                );

                $med_columns = implode(", ", array_keys($add_adunit_Objs));
                $med_values = implode("','", array_values($add_adunit_Objs));

                OA_Dal_Delivery_query("DELETE FROM mediation_app_adunit_details WHERE adunit_id = " . $aFields['zoneid']);

                OA_Dal_Delivery_query("INSERT INTO `mediation_app_adunit_details` ($med_columns) VALUES ('$med_values')");



                if ($_POST['delivery'] == 8) {
                    $layoutposition = $_POST['layout'];
                    $reward = implode("|", $_POST['reward']);
                    $amt = implode("|", $_POST['amount']);

                    OA_Dal_Delivery_query("DELETE FROM mediation_adunit_rewards_details WHERE adunit_id = " . $aFields['zoneid']);
                    OA_Dal_Delivery_query("INSERT INTO `mediation_adunit_rewards_details` (adunit_id,reward_curen_val,reward_amt,) VALUES ('" . $aFields['zoneid'] . "','" . $reward . "','" . $amt . "')");
                }
            } else {
                OA_Dal_Delivery_query("DELETE FROM mediation_app_adunit_details WHERE adunit_id = " . $aFields['zoneid']);


                OA_Dal_Delivery_query("DELETE FROM mediation_adunit_rewards_details WHERE adunit_id = " . $aFields['zoneid']);
            }







            // Reset append codes which called this zone
            $doZones = OA_Dal::factoryDO('zones');
            $doZones->appendtype = phpAds_ZoneAppendZone;

            if (OA_Permission::isAccount(OA_ACCOUNT_MANAGER)) {
                $doZones->addReferenceFilter('agency', OA_Permission::getEntityId());
            } elseif (OA_Permission::isAccount(OA_ACCOUNT_TRAFFICKER)) {
                $doZones->addReferenceFilter('affiliates', OA_Permission::getEntityId());
            }
            $doZones->find();

            while ($doZones->fetch() && $row = $doZones->toArray()) {
                $append = phpAds_ZoneParseAppendCode($row['append']);

                if ($append[0]['zoneid'] == $aFields['zoneid']) {
                    $doZonesClone = clone ($doZones);
                    $doZonesClone->appendtype = phpAds_ZoneAppendRaw;
                    $doZonesClone->append = '';
                    $doZonesClone->update();
                }
            }

            if ($type_changed && $aFields['delivery'] == MAX_ZoneEmail) {
                // Unlink all campaigns/banners linked to this zone
                $aPlacementZones = Admin_DA::getPlacementZones(['zone_id' => $aFields['zoneid']], true, 'placement_id');
                if (!empty($aPlacementZones)) {
                    foreach ($aPlacementZones as $placementId => $aPlacementZone) {
                        Admin_DA::deletePlacementZones(['zone_id' => $aFields['zoneid'], 'placement_id' => $placementId]);
                    }
                }
                $aAdZones = Admin_DA::getAdZones(['zone_id' => $aFields['zoneid']], false, 'ad_id');
                if (!empty($aAdZones)) {
                    foreach ($aAdZones as $adId => $aAdZone) {
                        Admin_DA::deleteAdZones(['zone_id' => $aFields['zoneid'], 'ad_id' => $adId]);
                    }
                }
            } elseif ($size_changed) {
                $aZone = Admin_DA::getZone($aFields['zoneid']);

                // Loop through all appended banners and make sure that they still fit...
                $aAds = Admin_DA::getAdZones(['zone_id' => $aFields['zoneid']], false, 'ad_id');
                if (!empty($aAds)) {
                    foreach ($aAds as $adId => $aAd) {
                        $aAd = Admin_DA::getAd($adId);
                        if (
                            (($aZone['type'] == phpAds_ZoneText) && ($aAd['type'] != 'txt'))
                            || (($aAd['width'] != $aZone['width']) && ($aZone['width'] != -1))
                            || (($aAd['height'] != $aZone['height']) && ($aZone['height'] != -1))
                        ) {
                            Admin_DA::deleteAdZones(['zone_id' => $aFields['zoneid'], 'ad_id' => $adId]);
                        }
                    }
                }

                // Check if any campaigns linked to this zone have ads that now fit.
                // If so, link them to the zone.
                $aPlacementZones = Admin_DA::getPlacementZones(['zone_id' => $aFields['zoneid']], true);
                if (!empty($aPlacementZones)) {
                    foreach ($aPlacementZones as $aPlacementZone) {
                        // get ads in this campaign
                        $aAds = Admin_DA::getAds(['placement_id' => $aPlacementZone['placement_id']], true);
                        foreach ($aAds as $adId => $aAd) {
                            Admin_DA::addAdZone(['zone_id' => $aFields['zoneid'], 'ad_id' => $adId]);
                        }
                    }
                }
            }
            if ($oComponent && method_exists($oComponent, 'processZoneForm')) {
                $oComponent->processZoneForm($aFields);
            }

            // Queue confirmation message
            $translation = new OX_Translation();
            $translated_message = $translation->translate(
                $GLOBALS['strZoneHasBeenUpdated'],
                [
                    MAX::constructURL(MAX_URL_ADMIN, "zone-edit.php?affiliateid=" . $aFields['affiliateid'] . "&zoneid=" . $aFields['zoneid']),
                    htmlspecialchars($aFields['zonename'])
                ]
            );
            OA_Admin_UI::queueMessage($translated_message, 'local', 'confirm', 0);

            OX_Admin_Redirect::redirect("zone-edit.php?affiliateid=" . $aFields['affiliateid'] . "&zoneid=" . $aFields['zoneid']);
        }
        // Add
        else {
            $doZones = OA_Dal::factoryDO('zones');
            $doZones->affiliateid = $aFields['affiliateid'];
            $doZones->zonename = $aFields['zonename'];
            $doZones->zonetype = phpAds_ZoneCampaign;
            $doZones->description = $aFields['description'];
            $doZones->comments = $aFields['comments'];
            $doZones->width = $aFields['width'];
            $doZones->height = $aFields['height'];
            $doZones->delivery = $aFields['delivery'];
            $doZones->oac_category_id = $aFields['oac_category_id'];

            $doZones->delivery_type = $aFields['delivery_type'];
            $doZones->adsize = serialize($_POST['adsize']);
            $doZones->mobileapptype = $aFields['mobileapptype'];
            $doZones->reward = $aFields['reward'];
            $doZones->position = $aFields['position'];
            $doZones->amount = $aFields['amount'];
            $doZones->layout = $aFields['layout'];
            $doZones->adposition = $aFields['adposition'];
            $doZones->adinterval = $aFields['adinterval'];
            $doZones->natimg_interval = $aFields['natimg_interval'];
            $doZones->natimg_position = $aFields['natimg_position'];

            // The following fields are NOT NULL but do not get values set in the form.
            // Should these fields be changed to NULL in the schema or should they have a default value?
            $doZones->category = '';
            $doZones->ad_selection = '';
            $doZones->chain = '';
            $doZones->prepend = '';
            $doZones->append = '';

            $doZones->show_capped_no_cookie = 0;

            $aFields['zoneid'] = $doZones->insert();


            if ($_POST['is_mediation'] == 1) {
                $add_adunit_Objs = array(
                    "adunit_id" => $aFields['zoneid'],
                    "adunit_name" => $_POST['zonename'],
                    "device_type" => $_POST['device_type'],
                    "ad_format" => $aFields['delivery'],
                    "refresh_interval" => $_POST['ref_inter_val'],
                    "layout_type" => $_POST['layout'],
                    "native_Place_ads" => $_POST['adinterval'],
                    "native_ad_position" => $_POST['adposition'],
                    "callback_url" => $_POST['call_bk_url'],
                    "is_afterplace_nat_ad" => ($_POST['adinterval'] > 0 ? 1 : 0),
                    "width" => $_POST['width'],
                    "height" => $_POST['height'],
                    "app_id" => $aFields['affiliateid'],
                    "added_date" => date("Y-m-d H:i:s"),
                    "affiliateid" => $aFields['affiliateid'],
                    "dj_mobile_ad_type" => $_POST['mobile_type'],
                    "dj_zone_type" => $ad_format

                );

                $table_prefix = $GLOBALS['_MAX']['CONF']['table']['prefix'];

                $ad_size = serialize($_POST['adsize']);
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones SET adsize='" . $ad_size . "', delivery_type = '" . $aFields['delivery_type'] . "'  WHERE zoneid = " . $aFields['zoneid']);

                $med_columns = implode(", ", array_keys($add_adunit_Objs));
                $med_values = implode("','", array_values($add_adunit_Objs));

                OA_Dal_Delivery_query("INSERT INTO `mediation_app_adunit_details` ($med_columns) VALUES ('$med_values')");

                if ($_POST['delivery'] == 8) {
                    $layoutposition = $_POST['layout'];
                    $reward = implode("|", $_POST['reward']);
                    $amt = implode("|", $_POST['amount']);

                    OA_Dal_Delivery_query("INSERT INTO `mediation_adunit_rewards_details` (adunit_id,reward_curen_val,reward_amt) VALUES ('" . $aFields['zoneid'] . "','" . $reward . "','" . $amt . "')");
                    OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set delivery=8, width='" . $aFields['width'] . "', height='" . $aFields['height'] . "', reward='" . $reward . "', amount='" . $amt . "', position='" . $aFields['position'] . "', layout='" . $layoutposition . "', adinterval='', adposition='' WHERE zoneid =" . $aFields['zoneid']);
                }
                if ($_POST['delivery'] == 11) {


                    OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set delivery=11  WHERE zoneid =" . $aFields['zoneid']);

                }
            }

            $mobileapp = $_POST['mobileapptype'];

            if ($aFields['delivery'] == 7) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "' where zoneid=" . $aFields['zoneid']);
            }

            if ($_POST['delivery'] == 8) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "',position='" . $aFields['position'] . "' where zoneid=" . $aFields['zoneid']);
                if (isset($aFields['reward']) && isset($aFields['amount'])) {
                    $layoutposition = $_POST['layout'];
                    $reward = implode("|", $_POST['reward']);
                    $amt = implode("|", $_POST['amount']);
                    OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set reward='" . $reward . "',amount='" . $amt . "',layout='" . $layoutposition . "' where zoneid =" . $aFields['zoneid']);
                }
            }
            if ($_POST['delivery'] == 10) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set delivery=10, width= '" . $aFields['width'] . "', height= '" . $aFields['height'] . "',  position='', amount='', reward='', adposition='', adinterval='' WHERE zoneid=" . $aFields['zoneid']);
            }
            if ($_POST['delivery'] == 9) {
                $nativepos = $_POST['adposition'];
                $nativeads = $_POST['adinterval'];

                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set adposition='" . $nativepos . "',adinterval='" . $nativeads . "',mobileapptype='" . $mobileapp . "' where zoneid =" . $aFields['zoneid']);
            }

            if ($_POST['delivery'] == 10) {

                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set mobileapptype='" . $mobileapp . "' where zoneid=" . $aFields['zoneid']);

                $layoutposition = $_POST['layout'];
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set layout='" . $layoutposition . "',reward='',position='',amount='' where zoneid=" . $aFields['zoneid']);
            }

            if ($_POST['app_select'] == 1) {
                OA_Dal_Delivery_query("UPDATE {$table_prefix}zones set app_select='" . $_POST['app_select'] . "',mobileapptype='" . $mobileapp . "' where zoneid =" . $aFields['zoneid']);
            }



            if ($oComponent && method_exists($oComponent, 'processZoneForm')) {
                $oComponent->processZoneForm($aFields);
            }

            // Queue confirmation message
            $translation = new OX_Translation();
            $translated_message = $translation->translate($GLOBALS['strZoneHasBeenAdded'], [
                MAX::constructURL(MAX_URL_ADMIN, 'zone-edit.php?affiliateid=' . $aFields['affiliateid'] . '&zoneid=' . $aFields['zoneid']),
                htmlspecialchars($aFields['zonename'])
            ]);
            OA_Admin_UI::queueMessage($translated_message, 'local', 'confirm', 0);

            OX_Admin_Redirect::redirect("affiliate-zones.php?affiliateid=" . $aFields['affiliateid']);
        }
    }

    return $errors;
}


/*-------------------------------------------------------*/
/* Display page                                          */
/*-------------------------------------------------------*/
function displayPage($zone, $form, $zoneErrors = null)
{
    //header and breadcrumbs
    $pageName = basename($_SERVER['SCRIPT_NAME']);
    $agencyId = OA_Permission::getAgencyId();
    $aEntities = ['affiliateid' => $zone['affiliateid'], 'zoneid' => $zone['zoneid']];

    $aOtherPublishers = Admin_DA::getPublishers(['agency_id' => $agencyId]);
    $aOtherZones = Admin_DA::getZones(['publisher_id' => $zone['affiliateid']]);
    MAX_displayNavigationZone($pageName, $aOtherPublishers, $aOtherZones, $aEntities);

    //get template and display form
    $oTpl = new OA_Admin_Template('zone-edit.html');
    $oTpl->assign('zoneid', $zone['zoneid']);
    $oTpl->assign('zoneHeight', $zone["height"]);
    $oTpl->assign('zoneWidth', $zone["width"]);

    $oTpl->assign('zoneErrors', $zoneErrors);
    $oTpl->assign('form', $form->serialize());

    $oTpl->display();

    //footer
    phpAds_PageFooter();
}
